<p><span>
{{ authors }}
</span></p>
<p>
    in <em>{{ journal }}</em>, {{ volume }} ({{ year }}). DOI: {{ doi }}
</p>
<div class="accordion-inner">
    <h4>Abstract</h4>
    <p> {{ description }} </p>
</div>
<div class="accordion-inner">
    {{ links }}
</div>