<p>
{%- if authors|length > 0 -%}
    {{ authors[0].index_name }} et al.:
{%- endif -%}
{%- if doi is ne("") -%}
    <a href="http://dx.doi.org/{{ doi }}"><b>{{ title }}</b></a>
{%- endif -%}
{%- if doi is eq("") -%}
    <b>{{ title }}</b>
{%- endif -%}
in {{ journal }}, {{ volume }} ({{ year }}).
</p>